"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.TableText = exports.TableCell = exports.TableHead = exports.Table = void 0;
const react_1 = __importDefault(require("react"));
const native_1 = __importDefault(require("@emotion/native"));
const react_native_1 = require("react-native");
const values_js_1 = __importDefault(require("values.js"));
const Grid_1 = require("@procyon/components/Grid");
const Stack_1 = require("@procyon/components/Stack");
const ThemeProvider_1 = require("@procyon/styles/ThemeProvider");
const Table = ({ headers, rows, nthHighlight = true, cols, layout, }) => {
    const { theme } = (0, ThemeProvider_1.useTheme)();
    const defaultLayout = { sm: new Array(headers.length).fill(1) };
    const defaultCols = { sm: headers.length };
    return (react_1.default.createElement(TableContainer, { direction: "column" },
        react_1.default.createElement(Grid_1.Grid, { cols: cols !== null && cols !== void 0 ? cols : defaultCols, layout: layout !== null && layout !== void 0 ? layout : defaultLayout, style: {
                row: {
                    backgroundColor: theme.palette.primary.main,
                    borderTopLeftRadius: theme.rounded.small,
                    borderTopRightRadius: theme.rounded.small,
                },
                cell: {
                    justifyContent: 'center',
                },
            } }, headers.map((Col, i) => (react_1.default.createElement(Col, { key: i, cols: { xs: 1 } })))),
        rows.map((row, r) => {
            const isNth = nthHighlight && (r + 1) % 2 === 0;
            return (react_1.default.createElement(Grid_1.Grid, { key: r, cols: cols !== null && cols !== void 0 ? cols : defaultCols, layout: layout !== null && layout !== void 0 ? layout : defaultLayout, style: {
                    row: Object.assign({ backgroundColor: isNth
                            ? new values_js_1.default(theme.palette.background.dark).tint(80).rgbString()
                            : 'transparent' }, (r === rows.length - 1 && {
                        borderBottomLeftRadius: theme.rounded.small,
                        borderBottomRightRadius: theme.rounded.small,
                    })),
                    cell: {
                        justifyContent: 'center',
                    },
                } }, row.map((Cell, c) => (react_1.default.createElement(Cell, { key: c, cols: { sm: 1 } })))));
        })));
};
exports.Table = Table;
const TableContainer = (0, native_1.default)(Stack_1.Stack)(({ theme }) => {
    return {
        borderRadius: theme.rounded.small,
    };
});
exports.TableHead = (0, native_1.default)(react_native_1.View)(({ theme }) => {
    return {
        justifyContent: 'center',
        padding: theme.spacing.md,
    };
});
exports.TableCell = (0, native_1.default)(react_native_1.View)(({ theme }) => {
    return {
        justifyContent: 'center',
        padding: theme.spacing.md,
    };
});
exports.TableText = (0, native_1.default)(react_native_1.Text)(({ theme, head }) => {
    return Object.assign({}, (head
        ? {
            color: theme.palette.primary.light,
        }
        : {
            color: theme.palette.text.main,
        }));
});
